'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _url = require('url');

var _url2 = _interopRequireDefault(_url);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

/**
 * @SERVER
 */
var ServerHttpRequest = function () {

  /**
   * @param {http.incomingMessage} httpRequest
   * @param {number} maxRequestBodyLength
   */


  /**
   * @type {Object}
   */
  function ServerHttpRequest(httpRequest, maxRequestBodyLength) {
    _classCallCheck(this, ServerHttpRequest);

    this._httpRequest = httpRequest;
    this._parsedUrl = _url2.default.parse(httpRequest.url, true);
    this._maxRequestBodyLength = maxRequestBodyLength;
  }

  /**
   * @param {string} givenHostPath
   * @returns {boolean}
   */


  /**
   * @type {number}
   */

  /**
   * @type {http.incomingMessage}
   */


  _createClass(ServerHttpRequest, [{
    key: 'startsWith',
    value: function startsWith(givenHostPath) {
      var hostAndPath = _path2.default.join(this.getHost(), this.getPath());
      return hostAndPath.substr(0, givenHostPath.length) == givenHostPath;
    }

    /**
     * @returns {string}
     */

  }, {
    key: 'getMethod',
    value: function getMethod() {
      return this._httpRequest.method;
    }

    /**
     * @returns {boolean}
     */

  }, {
    key: 'isSecure',
    value: function isSecure() {
      // TODO: Create default nginx configuration for usage, use our own architecture, create contract to know whether this is https or not (use header? x-forwarded-proto like our arch).
      // TODO: Make this configurable.
      return this._httpRequest.headers['x-forwarded-proto'] === 'https';
    }

    /**
     * @returns {Object}
     */

  }, {
    key: 'getHeaders',
    value: function getHeaders() {
      return this._httpRequest.headers;
    }

    /**
     * @returns {string}
     */

  }, {
    key: 'getDomain',
    value: function getDomain() {
      var hostSplit = this.getHost().split(':');
      return hostSplit[0].trim();
    }

    /**
     * @returns {string}
     */

  }, {
    key: 'getHost',
    value: function getHost() {
      return this._httpRequest.headers.host;
    }

    /**
     * @returns {string}
     */

  }, {
    key: 'getPath',
    value: function getPath() {
      return this._parsedUrl.pathname;
    }

    /**
     * @returns {string}
     */

  }, {
    key: 'getUrl',
    value: function getUrl() {
      return (this.isSecure() ? 'https' : 'http') + '://' + this.getDomain() + this.getPath();
    }

    /**
     * @return {string}
     */

  }, {
    key: 'getQuery',
    value: function getQuery() {
      return this._parsedUrl.search;
    }

    /**
     * @returns {Object}
     */

  }, {
    key: 'getQueryParams',
    value: function getQueryParams() {
      var result = {},
          key = void 0;
      for (key in this._parsedUrl.query) {
        result[key] = this._parsedUrl.query[key];
      }
      return result;
    }

    /**
     * @return {Promise}
     */

  }, {
    key: 'getBody',
    value: function getBody() {
      var _this = this;

      return new Promise(function (resolve, reject) {
        if (_this._httpRequest.method === 'POST') {
          var requestBody = '';

          _this._httpRequest.on('data', function (chunk) {
            requestBody += chunk;

            if (requestBody.length > this._maxRequestBodyLength) {
              this._httpRequest.connection.destroy();
              requestBody = new Error('Request data exceed maximum length');
            }
          }).on('end', function () {
            if (requestBody instanceof Error) reject(requestBody);else resolve(requestBody);
          });
        }
      });
    }
  }]);

  return ServerHttpRequest;
}();

exports.default = ServerHttpRequest;
//# sourceMappingURL=ServerHttpRequest.js.map